pub struct RuntimeConfig {
pub runtime_path: String,
pub runtime_abi: Option<String>,
pub runtime_args: Vec<String>,
}Expand description
Runtime configuration for delegating binary execution to userland
This structure defines how a binary format should be executed via a userland runtime instead of being loaded directly by the kernel.
Examples
- MS-DOS binaries executed via DOSBox (Linux ABI)
- Wasm binaries executed via a Scarlet-native Wasm runtime
- Java bytecode executed via a JVM
Fields
runtime_path: StringPath to the runtime executable in the VFS
runtime_abi: Option<String>ABI that the runtime itself uses If None, runtime’s ABI will be auto-detected
runtime_args: Vec<String>Additional arguments to pass to the runtime before the target binary Example: [“–emulate”, “dos”] for DOSBox